summaryrefslogtreecommitdiffstats
path: root/kscd/configWidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kscd/configWidget.cpp')
-rw-r--r--kscd/configWidget.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kscd/configWidget.cpp b/kscd/configWidget.cpp
index bae787e9..4d8e03fb 100644
--- a/kscd/configWidget.cpp
+++ b/kscd/configWidget.cpp
@@ -45,8 +45,8 @@ extern "C" {
class SpecialComboBox : public KComboBox
{
public:
- SpecialComboBox(TQWidget* parent, const char* name)
- : KComboBox(parent, name)
+ SpecialComboBox(TQWidget* tqparent, const char* name)
+ : KComboBox(tqparent, name)
{}
// TQComboBox::setCurrentText replaces the current text if
@@ -59,14 +59,14 @@ public:
} ;
/*
* Constructs a configWidget which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-configWidget::configWidget(KSCD* player, TQWidget* parent, const char* name)
- : configWidgetUI(parent, name),
+configWidget::configWidget(KSCD* player, TQWidget* tqparent, const char* name)
+ : configWidgetUI(tqparent, name),
mPlayer(player)
{
if (!name)
@@ -59,14 +59,14 @@ public:
} ;
/*
- * Constructs a configWidget which is a child of 'parent', with the
+ * Constructs a configWidget which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*